comparison/less_equal.hpp

The comparison/less_equal.hpp header defines macros that compare for equality or lesser magnitude.

#### Usage

#include <boost/preprocessor/comparison/less_equal.hpp>

#### Contents

- BOOST_PP_LESS_EQUAL
- BOOST_PP_LESS_EQUAL_D

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)